@@ -7,7 +7,7 @@ import tempfile
 import unittest
 import uuid
 
-from octue import Runner
+from octue import REPOSITORY_ROOT, Runner
 from octue.utils.processes import ProcessesContextManager
 
 from ..base import BaseTestCase
@@ -69,9 +69,11 @@ class TemplateAppsTestCase(BaseTestCase):
         analysis = runner.run()
         analysis.finalise(output_dir=os.path.join("data", "output"))
 
+    @unittest.skip(reason="See issue https://github.com/octue/octue-sdk-python/issues/385")
     def test_using_manifests(self):
         """Ensure the using-manifests template app works correctly."""
         self.set_template("template-using-manifests")
+
         runner = Runner(
             app_src=self.template_path,
             twine=self.template_twine,
@@ -80,8 +82,9 @@ class TemplateAppsTestCase(BaseTestCase):
         )
 
         analysis = runner.run(input_manifest=os.path.join("data", "input", "manifest.json"))
-        analysis.finalise(output_dir=os.path.join("data", "output"))
-        self.assertTrue(os.path.isfile(os.path.join("data", "output", "cleaned_met_mast_data", "cleaned.csv")))
+        analysis.finalise()
+
+        self.assertTrue(os.path.isfile(os.path.join("cleaned_met_mast_data", "cleaned.csv")))
 
     @unittest.skipIf(condition=os.name == "nt", reason="See issue https://github.com/octue/octue-sdk-python/issues/229")
     def test_child_services_template(self):
@@ -89,37 +92,37 @@ class TemplateAppsTestCase(BaseTestCase):
         collected from them). This template has a parent app and two children - an elevation app and wind speed app. The
         parent sends coordinates to both children, receiving the elevation and wind speed from them at these locations.
         """
-        cli_path = os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(__file__))), "octue", "cli.py")
+        cli_path = os.path.join(REPOSITORY_ROOT, "octue", "cli.py")
         self.set_template("template-child-services")
 
         elevation_service_path = os.path.join(self.template_path, "elevation_service")
         elevation_service_uuid = str(uuid.uuid4())
+
         elevation_process = subprocess.Popen(
             [
                 sys.executable,
                 cli_path,
                 "start",
-                f"--app-dir={elevation_service_path}",
-                f"--twine={os.path.join(elevation_service_path, 'twine.json')}",
-                f"--config-dir={os.path.join(elevation_service_path, 'data', 'configuration')}",
+                "--service-configuration-path=octue.yaml",
                 f"--service-id={elevation_service_uuid}",
                 "--delete-topic-and-subscription-on-exit",
-            ]
+            ],
+            cwd=elevation_service_path,
         )
 
         wind_speed_service_path = os.path.join(self.template_path, "wind_speed_service")
         wind_speed_service_uuid = str(uuid.uuid4())
+
         wind_speed_process = subprocess.Popen(
             [
                 sys.executable,
                 cli_path,
                 "start",
-                f"--app-dir={wind_speed_service_path}",
-                f"--twine={os.path.join(wind_speed_service_path, 'twine.json')}",
-                f"--config-dir={os.path.join(wind_speed_service_path, 'data', 'configuration')}",
+                "--service-configuration-path=octue.yaml",
                 f"--service-id={wind_speed_service_uuid}",
                 "--delete-topic-and-subscription-on-exit",
-            ]
+            ],
+            cwd=wind_speed_service_path,
         )
 
         with ProcessesContextManager(processes=(elevation_process, wind_speed_process)):
@@ -130,8 +133,8 @@ class TemplateAppsTestCase(BaseTestCase):
             # the file remains the same so this test tests the template as closely as possible.
             with tempfile.TemporaryDirectory() as temporary_directory:
 
-                with open(os.path.join(parent_service_path, "data", "configuration", "children.json")) as f:
-                    template_children = json.load(f)
+                with open(os.path.join(parent_service_path, "app_configuration.json")) as f:
+                    template_children = json.load(f)["children"]
 
                 template_children[0]["id"] = wind_speed_service_uuid
                 template_children[1]["id"] = elevation_service_uuid
